// Copyright  1997 - 2001, Paul C. Gregory
//
// Contact: pgregory@aqsis.com
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


/** \file
		\brief Global Aqsis include to include all files required within Aqsis
		\author Paul C. Gregory (pgregory@aqsis.com)
*/

//? Is .h included already?
#ifndef AQSIS_H_INCLUDED
#define AQSIS_H_INCLUDED 1

#ifdef HAVE_CONFIG_H
#include	"config.h"
#else
#ifdef	__GNUC__
#ifndef __APPLE__
#error " If this is a POSIX system you should be sure to run configure"
#endif /* __APPLE__ */
#endif /* __GNUC__ */
#endif /* HAVE_CONFIG_H */

#include	<assert.h>

#include	"aqsis_types.h"
#include	"aqsis_compiler.h"


#endif // AQSIS_H_INCLUDED
